register_checks

Macro register_checks 

macro_rules! register_checks {
    { $( $ty:ty { $( $name:expr => $tr:ty, )* }, )* } => { ... };
}
Register configuration structures with inventory.

A single check can implement multiple check traits, so this macro accepts multiple checks and multiple registrations with the same check. Ideally, check names should be unique globally, but nothing enforces this at the registration level.

Example

register_checks! {
    CheckConfig {
        "name" => CommitCheckConfig,
        "name/topic" => TopicCheckConfig,
    },
    OtherCheckConfig {
        "other_check" => BranchCheckConfig,
    },
}