pub trait IntoCheck: DeserializeOwned {
type Check;
// Required method
fn into_check(self) -> Self::Check;
}Expand description
Trait for a deserialization structure of a check.
This trait should be implemented for any structure which can be deserialized and construct a check.
Required Associated Types
Required Methods
Sourcefn into_check(self) -> Self::Check
fn into_check(self) -> Self::Check
Create a new instance of the check from the configuration.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".